@@ -1,3 +1,4 @@
+// clang-format off
 /*
  * KDiff3 - Text Diff And Merge Tool
  *
@@ -8,6 +9,7 @@
 // clang-format on
 
 #ifndef MERGEEDITLINE_H
+#define MERGEEDITLINE_H
 
 #include "diff.h"
 #include "LineRef.h"
@@ -36,7 +38,7 @@ class MergeEditLine
         mChanged = false;
         mStr = QString();
     }
-    Q_REQUIRED_RESULT inline bool isConflict() const { return mSrc == e_SrcSelector::None && !mLineRemoved && !mChanged; }
+    [[nodiscard]] inline bool isConflict() const { return mSrc == e_SrcSelector::None && !mLineRemoved && !mChanged; }
 
     void setRemoved(e_SrcSelector src = e_SrcSelector::None)
     {
@@ -45,9 +47,9 @@ class MergeEditLine
         mStr = QString();
         mChanged = (src == e_SrcSelector::None);
     }
-    Q_REQUIRED_RESULT inline bool isRemoved() const { return mLineRemoved; }
+    [[nodiscard]] inline bool isRemoved() const { return mLineRemoved; }
 
-    Q_REQUIRED_RESULT inline bool isEditableText() const { return !isConflict(); }
+    [[nodiscard]] inline bool isEditableText() const { return !isConflict(); }
 
     void setString(const QString& s)
     {
@@ -56,8 +58,8 @@ class MergeEditLine
         mSrc = e_SrcSelector::None;
         mChanged = true;
     }
-    Q_REQUIRED_RESULT QString getString(const std::shared_ptr<LineDataVector>& pLineDataA, const std::shared_ptr<LineDataVector>& pLineDataB, const std::shared_ptr<LineDataVector>& pLineDataC) const;
-    Q_REQUIRED_RESULT inline bool isModified() const { return mChanged; }
+    [[nodiscard]] QString getString() const;
+    [[nodiscard]] inline bool isModified() const { return mChanged; }
 
     void setSource(e_SrcSelector src, bool bLineRemoved)
     {
@@ -83,14 +85,14 @@ class MergeEditLine
     bool mChanged;
 };
 
-class MergeLine
+class MergeBlock
 {
   private:
-    friend class MergeLineList;
+    friend class MergeBlockList;
 
     Diff3LineList::const_iterator mId3l;
-    LineIndex d3lLineIdx = -1;    // Needed to show the correct window pos.
-    LineCount srcRangeLength = 0; // how many src-lines have these properties
+    LineType d3lLineIdx = -1;    // Needed to show the correct window pos.
+    LineType srcRangeLength = 0; // how many src-lines have these properties
     e_MergeDetails mergeDetails = e_MergeDetails::eDefault;
     bool bConflict = false;
     bool bWhiteSpaceConflict = false;
@@ -104,8 +106,8 @@ class MergeLine
 
     [[nodiscard]] inline e_SrcSelector source() const { return srcSelect; }
 
-    [[nodiscard]] inline LineIndex getIndex() const { return d3lLineIdx; }
-    [[nodiscard]] inline LineCount sourceRangeLength() const { return srcRangeLength; }
+    [[nodiscard]] inline LineType getIndex() const { return d3lLineIdx; }
+    [[nodiscard]] inline LineType sourceRangeLength() const { return srcRangeLength; }
 
     [[nodiscard]] inline bool isConflict() const { return bConflict; }
     [[nodiscard]] inline bool isWhiteSpaceConflict() const { return bWhiteSpaceConflict; }
@@ -119,53 +121,53 @@ class MergeLine
 
     [[nodiscard]] inline e_MergeDetails details() const { return mergeDetails; }
 
-    [[nodiscard]] inline LineCount lineCount() const { return SafeInt<qint32>(list().size()); }
+    [[nodiscard]] inline LineType lineCount() const { return SafeInt<qint32>(list().size()); }
 
-    void split(MergeLine& ml2, qint32 d3lLineIdx2) // The caller must insert the ml2 after this ml in the m_mergeLineList
+    void split(MergeBlock& mb2, LineType d3lLineIdx2) // The caller must insert the mb2 after this mb in the m_mergeLineList
     {
         if(d3lLineIdx2 < d3lLineIdx || d3lLineIdx2 >= d3lLineIdx + srcRangeLength)
         {
             assert(false);
             return; //Error
         }
-        ml2.mergeDetails = mergeDetails;
-        ml2.bConflict = bConflict;
-        ml2.bWhiteSpaceConflict = bWhiteSpaceConflict;
-        ml2.bDelta = bDelta;
-        ml2.srcSelect = srcSelect;
+        mb2.mergeDetails = mergeDetails;
+        mb2.bConflict = bConflict;
+        mb2.bWhiteSpaceConflict = bWhiteSpaceConflict;
+        mb2.bDelta = bDelta;
+        mb2.srcSelect = srcSelect;
 
-        ml2.d3lLineIdx = d3lLineIdx2;
-        ml2.srcRangeLength = srcRangeLength - (d3lLineIdx2 - d3lLineIdx);
-        srcRangeLength = d3lLineIdx2 - d3lLineIdx; // current MergeLine controls fewer lines
-        ml2.mId3l = mId3l;
-        for(qint32 i = 0; i < srcRangeLength; ++i)
-            ++ml2.mId3l;
+        mb2.d3lLineIdx = d3lLineIdx2;
+        mb2.srcRangeLength = srcRangeLength - (d3lLineIdx2 - d3lLineIdx);
+        srcRangeLength = d3lLineIdx2 - d3lLineIdx; // current MergeBlock controls fewer lines
+        mb2.mId3l = mId3l;
+        for(LineType i = 0; i < srcRangeLength; ++i)
+            ++mb2.mId3l;
 
-        ml2.mMergeEditLineList.clear();
+        mb2.mMergeEditLineList.clear();
         // Search for best place to splice
         for(MergeEditLineList::iterator i = mMergeEditLineList.begin(); i != mMergeEditLineList.end(); ++i)
         {
-            if(i->id3l() == ml2.mId3l)
+            if(i->id3l() == mb2.mId3l)
             {
-                ml2.mMergeEditLineList.splice(ml2.mMergeEditLineList.begin(), mMergeEditLineList, i, mMergeEditLineList.end());
+                mb2.mMergeEditLineList.splice(mb2.mMergeEditLineList.begin(), mMergeEditLineList, i, mMergeEditLineList.end());
                 return;
             }
         }
-        ml2.mMergeEditLineList.push_back(MergeEditLine(ml2.mId3l));
+        mb2.mMergeEditLineList.push_back(MergeEditLine(mb2.mId3l));
     }
 
-    void join(MergeLine& ml2) // The caller must remove the ml2 from the m_mergeLineList after this call
+    void join(MergeBlock& mb2) // The caller must remove the ml2 from the m_mergeLineList after this call
     {
-        srcRangeLength += ml2.srcRangeLength;
-        ml2.mMergeEditLineList.clear();
+        srcRangeLength += mb2.srcRangeLength;
+        mb2.mMergeEditLineList.clear();
         mMergeEditLineList.clear();
         mMergeEditLineList.push_back(MergeEditLine(mId3l)); // Create a simple conflict
-        if(ml2.bConflict) bConflict = true;
-        if(!ml2.bWhiteSpaceConflict) bWhiteSpaceConflict = false;
-        if(ml2.bDelta) bDelta = true;
+        if(mb2.bConflict) bConflict = true;
+        if(!mb2.bWhiteSpaceConflict) bWhiteSpaceConflict = false;
+        if(mb2.bDelta) bDelta = true;
     }
 
-    bool isSameKind(const MergeLine& ml2) const;
+    bool isSameKind(const MergeBlock& mb2) const;
 
     void mergeOneLine(const Diff3Line& diffRec, bool& bLineRemoved, bool bTwoInputs);
     void dectectWhiteSpaceConflict(const Diff3Line& d, const bool isThreeWay);
@@ -173,21 +175,16 @@ class MergeLine
     void removeEmptySource();
 };
 
-typedef std::list<MergeLine> MergeLineListImp;
-
-class MergeLineList
+class MergeBlockList: public std::list<MergeBlock>
 {
-  private:
-    MergeLineListImp mImp;
-
   public:
-    [[nodiscard]] inline const MergeLineListImp& list() const { return mImp; }
-    [[nodiscard]] inline MergeLineListImp& list() { return mImp; }
+    using std::list<MergeBlock>::list;
 
     void buildFromDiff3(const Diff3LineList& diff3List, bool isThreeway);
     void updateDefaults(const e_SrcSelector defaultSelector, const bool bConflictsOnly, const bool bWhiteSpaceOnly);
 
-    MergeLineListImp::iterator splitAtDiff3LineIdx(qint32 d3lLineIdx);
+    MergeBlockList::iterator splitAtDiff3LineIdx(qint32 d3lLineIdx);
 };
 
+inline std::shared_ptr<LineDataVector> gLineVector[4];
 #endif
