@@ -59,9 +59,8 @@ class MergeResultWindow: public QWidget
 
     void setupConnections(const KDiff3App* app);
 
-    static void initActions(KActionCollection* ac);
+    void initActions(KActionCollection* ac);
 
-    void connectActions() const;
     void reset();
 
     bool saveDocument(const QString& fileName, const char* encoding, e_LineEndStyle eLineEndStyle);
@@ -83,8 +82,8 @@ class MergeResultWindow: public QWidget
     [[nodiscard]] bool isUnsolvedConflictAtCurrent() const;
     [[nodiscard]] bool isUnsolvedConflictAboveCurrent() const;
     [[nodiscard]] bool isUnsolvedConflictBelowCurrent() const;
-    bool findString(const QString& s, LineRef& d3vLine, QtSizeType& posInLine, bool bDirDown, bool bCaseSensitive);
-    void setSelection(LineType firstLine, QtSizeType startPos, LineType lastLine, QtSizeType endPos);
+    bool findString(const QString& s, LineRef& d3vLine, qsizetype& posInLine, bool bDirDown, bool bCaseSensitive);
+    void setSelection(LineType firstLine, qsizetype startPos, LineType lastLine, qsizetype endPos);
     [[nodiscard]] e_OverviewMode getOverviewMode() const;
 
     void slotUpdateAvailabilities();
@@ -135,9 +134,6 @@ class MergeResultWindow: public QWidget
 
     std::shared_ptr<UndoRecord> mUndoRec;
 
-    std::shared_ptr<LineDataVector> m_pldA = nullptr;
-    std::shared_ptr<LineDataVector> m_pldB = nullptr;
-    std::shared_ptr<LineDataVector> m_pldC = nullptr;
     LineRef m_sizeA = 0;
     LineRef m_sizeB = 0;
     LineRef m_sizeC = 0;
@@ -295,6 +291,8 @@ class MergeResultWindow: public QWidget
     void updateAvailabilities();
     void showPopupMenu(const QPoint& point);
     void noRelevantChangesDetected();
+
+    void scrollToH(qsizetype pos);
 };
 
 class QLineEdit;
@@ -324,7 +322,7 @@ class WindowTitleWidget: public QWidget
     const char* getEncoding();
     void setFileName(const QString& fileName);
     QString getFileName();
-    void setEncodings(const char* pCodecForA, const char* pCodecForB, const char* pCodecForC);
+    void setEncodings(const QByteArray& pCodecForA, const QByteArray& pCodecForB, const QByteArray& pCodecForC);
     void setEncoding(const char* encoding);
     void setLineEndStyles(e_LineEndStyle eLineEndStyleA, e_LineEndStyle eLineEndStyleB, e_LineEndStyle eLineEndStyleC);
     e_LineEndStyle getLineEndStyle();
